@@ -31,6 +31,7 @@
 #include "asynchttpsubmit.h"
 #include "cache.h"
 #include "lookup.h"
+#include "logging.h"
 
 #include "config-musicbrainz.h"
 #ifdef HAVE_MUSICBRAINZ5
@@ -38,8 +39,6 @@
 #include "musicbrainz/asyncmusicbrainzlookup.h"
 #endif
 
-#include <kdebug.h>
-
 namespace KCDDB
 {
   class Client::Private
@@ -56,6 +55,7 @@ namespace KCDDB
       {
         delete cdInfoLookup;
         delete cdInfoSubmit;
+        qDeleteAll(pendingLookups);
       }
 
       Lookup * cdInfoLookup;
@@ -71,7 +71,7 @@ namespace KCDDB
   Client::Client()
     : d(new Private)
   {
-    d->config.readConfig();
+    d->config.load();
   }
 
   Client::~Client()
@@ -111,7 +111,7 @@ namespace KCDDB
 
     if ( trackOffsetList.count() <= 1 )
     {
-      kDebug(60010) << "Lookup called with empty offset list";
+	  qCDebug(LIBKCDDB) << "Lookup called with empty offset list";
       return NoRecordFound;
     }
 
@@ -119,7 +119,7 @@ namespace KCDDB
     {
       d->cdInfoList = Cache::lookup( trackOffsetList, config() );
 
-      kDebug(60010) << "Found " << d->cdInfoList.count() << " hit(s)";
+	  qCDebug(LIBKCDDB) << "Found " << d->cdInfoList.count() << " hit(s)";
 
       if ( !d->cdInfoList.isEmpty() )
       {
@@ -135,6 +135,8 @@ namespace KCDDB
     // just in case we have an info lookup hanging around, prevent mem leakage
     delete d->cdInfoLookup;
     d->cdInfoLookup = 0;
+    qDeleteAll(d->pendingLookups);
+    d->pendingLookups.clear();
 
     if ( blockingMode() )
     {
@@ -321,7 +323,7 @@ namespace KCDDB
         break;
       }
       default:
-        kDebug(60010) << "Unsupported transport: ";
+		qCDebug(LIBKCDDB) << "Unsupported transport: ";
 //          << CDDB::transportToString(d->config.submitTransport()) << endl;
         return UnknownError;
         break;
@@ -370,7 +372,4 @@ namespace KCDDB
   }
 }
 
-#include "client.moc"
-
-
 // vim:tabstop=2:shiftwidth=2:expandtab:cinoptions=(s,U1,m1
